@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2005 Zope Foundation and Contributors.
+# Copyright (c) 2005 Zope Corporation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -13,7 +13,7 @@
 ##############################################################################
 """Zope 3-specific testing code
 
-$Id: testing.py 124524 2012-03-05 20:49:01Z menesis $
+$Id: testing.py 106706 2009-12-17 19:42:23Z hannosch $
 """
 
 
@@ -26,7 +26,6 @@ import sys
 import transaction
 import unittest
 import urllib2
-import zope.app.testing
 import zope.testbrowser.browser
 
 
@@ -34,7 +33,8 @@ class PublisherConnection(object):
     """A ``urllib2`` compatible connection obejct."""
 
     def __init__(self, host, timeout=None):
-        self.caller = zope.app.testing.functional.HTTPCaller()
+        from zope.app.testing.functional import HTTPCaller
+        self.caller = HTTPCaller()
         self.host = host
 
     def set_debuglevel(self, level):
@@ -62,11 +62,9 @@ class PublisherConnection(object):
             handle_errors_key = 'X-Zope-Handle-Errors'
         else:
             handle_errors_key = 'X-zope-handle-errors'
-        handle_errors_header = headers.get(handle_errors_key, True)
+        handle_errors = headers.get(handle_errors_key, True)
         if handle_errors_key in headers:
             del headers[handle_errors_key]
-        # Translate string to boolean.
-        handle_errors = {'False': False}.get(handle_errors_header, True)
 
         # Construct the headers.
         header_chunks = []
